Module syntax

Module syntax 

TODO

Re-exports

pub use attrs::*;

Modules

attrs

Structs

Builds
The #[capi::builds(TYPE)] attribute.
Opaque
The #[capi::opaque(size = 42, align = 12)] attribute.
Trimmed
Converts ty to a string, but strips out whitespace.

Enums

Item
An item that can appear inside a C API.